from typing import List
from re import compile, Pattern
from zlib import crc32
from .cktypeinterface import CKTYPEINTERFACE


class CRC32(CKTYPEINTERFACE):
    NAME: str = "CRC32"
    EXT: List[str] = [".sfv"]
    SYNTAX: List[Pattern] = [
        # comment lines
        compile(r"^;*$"),
        # filepath checksum pair
        compile(r"^.* [0-9a-fA-F]{8}$"),
    ]
    REGEX: Pattern = compile(r"[0-9a-fA-F]{8}")
    NULL: str = "00000000"

    def __init__(self):
        self.cksum: int = 0

    def gensum(self, data: bytes):
        self.cksum = crc32(data, self.cksum)

    def reset(self):
        self.__init__()

    def __repr__(self) -> str:
        cstring = format(self.cksum, "x").upper()
        return cstring.rjust(8, "0")
